const template = document.createElement('template')

const getInnerHTML = that => {
  return `
  <style>
  .quickapp-block {
    position: fixed;
    bottom: 10px;
    width: 100%;
    height: 50px;
    display: flex;
    align-items: center;
    justify-content: center;
  }
  .open-in-quickapp {
    position: fixed;
    bottom: 10px;
    display: flex;
    align-items: center;
    justify-content: center;
    min-width: 160px;
    height: 50px;
    line-height: 50px;
    transform: translate(-50%, -50%);
    margin: auto;
    color: #ffffff;
    border: solid 0.125em transparent;
    border-radius: 25px;
    padding: 0 10px;
    text-decoration: none;
    transition: 0.2s ease-out;
    animation: animat 1.8s infinite;
    box-shadow: inset 0 0 0.125em rgb(255 255 255 / 75%);
    background: linear-gradient(#f8e7e8, #e30001, #bc0000) content-box, linear-gradient(-80deg, #f11f20, #9c1c1c, #f11f20) 0/37% 100% border-box;
    z-index: 999999;
  }
  @keyframes animat {
    0%{ transform: scale(.8); }
    50%{ transform: scale(1); }
    100%{ transform: scale(.8); }
  }
  </style>

  <div class="quickapp-block">
    <a href="${that.deeplink}"
      style="color: ${that.color};background-color: ${that.bgcolor};display: ${that.display}"
      class="open-in-quickapp"
      >${that.text}
    </a>
  </div>
`
}

class QuickappDeeplink extends HTMLElement {
  constructor() {
    super()
    template.innerHTML = getInnerHTML(this)
    this._shadowRoot = this.attachShadow({ mode: 'closed' })
    this._shadowRoot.appendChild(template.content.cloneNode(true))
  }

  get text() {
    return (
      this.getAttribute('text') || '快应用中打开'
    )
  }
  set text(v) {
    this.setAttribute('text')
  }

  get bgcolor() {
    return (
      this.getAttribute('bgcolor') || '#20a0ff'
    )
  }
  set bgcolor(v) {
    this.setAttribute('bgcolor')
  }

  get color() {
    return (
      this.getAttribute('color') || '#ffffff'
    )
  }
  set color(v) {
    this.setAttribute('color')
  }

  get brand() {
    return (
      this.getAttribute('brand') || 'vivo|Weixin|huawei|HUAWEI|oppo|OPPO'
    )
  }
  set brand(v) {
    this.setAttribute('brand')
  }

  get display() {
    const ua = navigator.userAgent
    const brandArr = this.brand.split('|')
    const isPermit = brandArr.some(brand => {
      return ua.includes(brand)
    })
    const isDisplay = this.isAndroidSystem() && isPermit && !this.isInQuickApp()
    return isDisplay ? 'flex' : 'none'
  }

  get deeplink() {
    const deeplink = this.getAttribute('deeplink') || 'hap://app/graceful.sentences.com'
    return `${deeplink}?path=${location.href}`
  }
  set deeplink(v) {
    this.setAttribute('deeplink')
  }

  isAndroidSystem() {
    const ua = window.navigator.userAgent
    return ua.indexOf('Android') > -1 || ua.indexOf('Adr') > -1
  }

  isInQuickApp() {
    try {
      system.postMessage({})
      return true
    } catch (error) {
      return false
    }
  }
}

window.customElements.define('quickapp-deeplink', QuickappDeeplink)
